# Operator Inference in Python

Operator Inference learns projection-based polynomial reduced-order models of dynamical systems from data.
See https://github.com/Willcox-Research-Group/rom-operator-inference-Python3.
